| Title: | Discrete Tempered Stable Distributions |
|---|---|
| Description: | Methods for evaluating the probability mass function, cumulative distribution function, and generating random samples from discrete tempered stable distributions. For more details see Grabchak (2021) <doi:10.1007/s11009-021-09904-3>. |
| Authors: | Sina Saba [aut, cre, cph] |
| Maintainer: | Sina Saba <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.1.1 |
| Built: | 2026-05-31 09:16:37 UTC |
| Source: | https://github.com/cran/DTS |
The probability mass function of the discrete tempered stable distribution.
ddts(x, alpha, eta, tp = c(1, 1), tf = "poisson-tweedie", zt = FALSE)ddts(x, alpha, eta, tp = c(1, 1), tf = "poisson-tweedie", zt = FALSE)
x |
vector of points. |
alpha |
Index of stability; Number in (0,1) |
eta |
A parameter, eta>0. |
tp |
A vector of tempering parameters. |
tf |
Tempering function. It can be one of the "discrete-stable", "discrete-truncated-stable", "discrete-pRDTS", "poisson-tweedie", "exp-tempering", "beta-prime-tempering", "Pareto-tempering". |
zt |
Logical. If True it calculates zero-truncated probabilities. |
A vector of probabilities.
M. Grabchak. Discrete tempered stable distributions. Methodology and Computing in Applied Probability, 24(3):1877-1890, 2021.
x <- 0:10 ddts(x, 0.5, 1)x <- 0:10 ddts(x, 0.5, 1)
Log-likelihood function for a discrete tempered stable distribution.
edts(pv, smpl, tf = "poisson-tweedie", zt = FALSE)edts(pv, smpl, tf = "poisson-tweedie", zt = FALSE)
pv |
A vector of parameters. |
smpl |
A sample data to be used for estimation. |
tf |
Tempering function. It can be one of the "discrete-stable", "discrete-truncated-stable", "discrete-pRDTS", "poisson-tweedie", "exp-tempering", "beta-prime-tempering", "Pareto-tempering". |
zt |
Logical. If True it calculates zero-truncated probabilities. |
A number. Negative of likelihood function.
M. Grabchak. Discrete tempered stable distributions. Methodology and Computing in Applied Probability, 24(3):1877-1890, 2021.
pv <- c(0.5, 1, 1) n <- 100 smpl <- rdts(n, 0.5, 1) edts(pv, smpl)pv <- c(0.5, 1, 1) n <- 100 smpl <- rdts(n, 0.5, 1) edts(pv, smpl)
The probability distribution of the discrete tempered stable distribution.
pdts(x, alpha, eta, tp = c(1, 1), tf = "poisson-tweedie", zt = FALSE)pdts(x, alpha, eta, tp = c(1, 1), tf = "poisson-tweedie", zt = FALSE)
x |
vector of points. |
alpha |
Index of stability; Number in (0,1) |
eta |
A parameter, eta>0. |
tp |
A vector of tempering parameters. |
tf |
Tempering function. It can be one of the "discrete-stable", "discrete-truncated-stable", "discrete-pRDTS", "poisson-tweedie", "exp-tempering", "beta-prime-tempering", "Pareto-tempering". |
zt |
Logical. If True it calculates zero-truncated probabilities. |
A vector of numbers.
M. Grabchak. Discrete tempered stable distributions. Methodology and Computing in Applied Probability, 24(3):1877-1890, 2021.
x <- 0:10 pdts(x, 0.5, 1)x <- 0:10 pdts(x, 0.5, 1)
Simulation from a discrete tempered stable distribution.
rdts(n, alpha, eta, tp = c(1, 1), tf = "poisson-tweedie", c = 1, zt = FALSE)rdts(n, alpha, eta, tp = c(1, 1), tf = "poisson-tweedie", c = 1, zt = FALSE)
n |
Number of observations. |
alpha |
Index of stability; Number in (0,1) |
eta |
A parameter, eta>0. |
tp |
A vector of tempering parameters. |
tf |
Tempering function. It can be one of the "discrete-stable", "discrete-truncated-stable", "discrete-pRDTS", "poisson-tweedie", "exp-tempering", "beta-prime-tempering", "Pareto-tempering". |
c |
The essential supremum of the tempering function. |
zt |
Logical. If True it calculates zero-truncated probabilities. |
A vector of observations from a DTS distributions.
M. Grabchak. Discrete tempered stable distributions. Methodology and Computing in Applied Probability, 24(3):1877-1890, 2021.
n <- 10 rdts(n, 0.5, 1)n <- 10 rdts(n, 0.5, 1)